package
Version:
v0.0.0-...-3e386e2
Opens a new window with list of versions in this module.
Published: Nov 26, 2020
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func ValidateRequest(data interface{}) (ok bool, errMsg []string)
验证表单数据
Source Files
¶
Click to show internal directories.
Click to hide internal directories.