package
Version:
v0.0.0-...-3e386e2
Opens a new window with list of versions in this module.
Published: Nov 26, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ErrMsg struct {
Code int
Error error
Result interface{}
}
type ListsResult struct {
Field interface{} `json:"field"`
Data interface{} `json:"data"`
}
分页列表结果
type Response struct {
Code int `json:"code"`
Message string `json:"message"`
Result interface{} `json:"result"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.