package
Version:
v0.0.0-...-3e386e2
Opens a new window with list of versions in this module.
Published: Nov 26, 2020
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func InArray(needle interface{}, haystack interface{}) bool
InArray in_array()
haystack supported types: slice, array or map
Source Files
¶
Click to show internal directories.
Click to hide internal directories.